@@ -1,4 +1,5 @@
 """Weather datapoint calculator."""
+
 from __future__ import annotations
 
 import datetime as dt
@@ -14,11 +15,11 @@ def _ftoc(fahrenheit: float | str) -> float:
 
 
 def _timestamp_to_datetime(timestamp: int) -> dt.datetime:
-    return dt.datetime.utcfromtimestamp(timestamp).replace(tzinfo=dt.timezone.utc)
+    return dt.datetime.fromtimestamp(timestamp, dt.timezone.utc)
 
 
 def weather_datapoints(
-    data: dict[str, str]
+    data: dict[str, str],
 ) -> dict[str, str | int | float | dt.datetime | None]:
     """Calculate and convert weather data."""
     mph_kmh = 1.60934
@@ -44,16 +45,18 @@ def weather_datapoints(
 
     # lightning
     if "lightning_time" in data:
-        if data["lightning_time"] is not None and data["lightning_time"] != "":
+        if data["lightning_time"]:
             data["lightning_time"] = _timestamp_to_datetime(int(data["lightning_time"]))
         else:
             data["lightning_time"] = None
     if "lightning_num" in data:
         data["lightning_num"] = int(data["lightning_num"])
     if "lightning" in data:
-        if data["lightning"] is not None and data["lightning"] != "":
+        if data["lightning"]:
             data["lightning"] = int(data["lightning"])
             data["lightning_mi"] = int(round(data["lightning"] * km_mi))
+        else:
+            data["lightning"] = None
 
     # temperatures
     if "tempf" in data:
@@ -148,6 +151,8 @@ def weather_datapoints(
     if "yrain_piezo" in data:
         data["yrain_piezo"] = float(data["yrain_piezo"])
         data["yrain_piezomm"] = round(data["yrain_piezo"] * in_mm, 1)
+    if "srain_piezo" in data:
+        data["srain_piezo"] = int(data["srain_piezo"])
 
     # Pressure
     if "baromrelin" in data:
@@ -178,13 +183,13 @@ def weather_datapoints(
     # Feels like
     if "tempf" in data and "humidity" in data and "windspeedmph" in data:
         feels_like = meteocalc.feels_like(
-            data["tempf"], data["windspeedmph"], data["humidity"]
+            data["tempf"], data["humidity"], data["windspeedmph"]
         )
         data["tempfeelsf"] = round(feels_like.f, 1)
         data["tempfeelsc"] = round(feels_like.c, 1)
 
     # Soil moisture (WH51)
-    for j in range(1, 9):
+    for j in range(1, 17):
         name = f"soilmoisture{j}"
         if name in data:
             data[name] = int(data[name])
@@ -267,7 +272,10 @@ def weather_datapoints(
                 else:
                     data[name] = float(data[name])
 
-    bat_full_names = ["ws90cap_volt"]
+    bat_full_names = [
+        "ws90cap_volt",
+        "console_batt",
+    ]
     for name in bat_full_names:
         if name in data:
             data[name] = float(data[name])
