@@ -1,4 +1,5 @@
 """aioEcoWitt API server."""
+
 from __future__ import annotations
 
 import logging
@@ -30,8 +31,9 @@ class EcoWittListener:
         self.site: None | web.TCPSite = None
 
         # internal data
-        self.last_values: dict[str, dict[str, str | int | float | None]] = {}
+        self.last_values: dict[str, dict[str, str | None]] = {}
         self.new_sensor_cb: list[Callable[[EcoWittSensor], None]] = []
+        self._warned_unknown: set[str] = set()
 
         # storage
         self.sensors: dict[str, EcoWittSensor] = {}
@@ -67,11 +69,13 @@ class EcoWittListener:
             if sensor is None:
                 # we have a new sensor
                 if datapoint not in SENSOR_MAP:
-                    _LOGGER.warning(
-                        "Unhandled sensor type %s value %s",
-                        datapoint,
-                        weather_data[datapoint],
-                    )
+                    if datapoint not in self._warned_unknown:
+                        self._warned_unknown.add(datapoint)
+                        _LOGGER.warning(
+                            "Unhandled sensor type %s value %s",
+                            datapoint,
+                            weather_data[datapoint],
+                        )
                     continue
                 metadata = SENSOR_MAP[datapoint]
 
@@ -98,7 +102,8 @@ class EcoWittListener:
         data = await request.post()
 
         # data is not a dict, it's a MultiDict
-        self.last_values[data["PASSKEY"]] = data
+        self.last_values[data["PASSKEY"]] = data.copy()
+        self.last_values[data["PASSKEY"]].pop("PASSKEY")
         self.process_data(data)
 
         return web.Response(text="OK")
