@@ -9,22 +9,6 @@ from .const import GW2000A_DATA, EASYWEATHER_DATA
 # pylint: disable=redefined-outer-name
 
 
-@pytest.fixture
-def ecowitt_server():
-    """EcoWitt server fixture."""
-    ecowitt_server = server.EcoWittListener()
-    yield ecowitt_server
-
-
-@pytest.fixture
-def ecowitt_http(event_loop, aiohttp_raw_server, aiohttp_client, ecowitt_server):
-    """EcoWitt HTTP fixture."""
-    raw_server = event_loop.run_until_complete(
-        aiohttp_raw_server(ecowitt_server.handler)
-    )
-    return event_loop.run_until_complete(aiohttp_client(raw_server))
-
-
 @pytest.mark.asyncio
 async def test_server_start(ecowitt_server, ecowitt_http) -> None:
     """Test server start."""
@@ -41,10 +25,12 @@ async def test_server_start(ecowitt_server, ecowitt_http) -> None:
     text = await resp.text()
     assert text == "OK"
 
-    assert len(sensors) == 47
-    assert len(ecowitt_server.sensors) == 47
+    assert len(sensors) == 52
+    assert len(ecowitt_server.sensors) == 52
     assert len(ecowitt_server.stations) == 1
 
+    assert "PASSKEY" not in ecowitt_server.last_values[GW2000A_DATA["PASSKEY"]]
+
 
 @pytest.mark.asyncio
 async def test_server_token(ecowitt_server, ecowitt_http) -> None:
@@ -67,8 +53,8 @@ async def test_server_token(ecowitt_server, ecowitt_http) -> None:
     text = await resp.text()
     assert text == "OK"
 
-    assert len(sensors) == 47
-    assert len(ecowitt_server.sensors) == 47
+    assert len(sensors) == 52
+    assert len(ecowitt_server.sensors) == 52
     assert len(ecowitt_server.stations) == 1
 
 
@@ -93,6 +79,6 @@ async def test_server_multi_stations(ecowitt_server, ecowitt_http) -> None:
     text = await resp.text()
     assert text == "OK"
 
-    assert len(sensors) == 86
-    assert len(ecowitt_server.sensors) == 86
+    assert len(sensors) == 91
+    assert len(ecowitt_server.sensors) == 91
     assert len(ecowitt_server.stations) == 2
